"""
Configs migration

Generation datetime: 2023-07-27 08:56:52.581624
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "931989a8"
DOWN_REVISION = "a9ccb943"


def upgradeASU(value):
    value["luna_lambda"] = False
    return value


def downgradeASU(value):
    value.pop("luna_lambda", None)
    return value


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_EVENTS_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-events service",
        newDescription="timeouts for http-request to luna-events service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-tasks"],
        newServices=["luna-api", "luna-handlers", "luna-lambda-unit", "luna-tasks"],
    ),
    LimitationToModify(
        limitationName="LUNA_PYTHON_MATCHER_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5100", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5100", "api_version": 1},
        oldDescription="LUNA Python Matcher address",
        newDescription="LUNA Python Matcher address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_PYTHON_MATCHER_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-python-matcher service",
        newDescription="timeouts for http-request to luna-python-matcher service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers"],
        newServices=["luna-api", "luna-handlers", "luna-lambda-unit"],
    ),
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-remote-sdk service",
        newDescription="timeouts for http-request to luna-remote-sdk service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers"],
        newServices=["luna-api", "luna-handlers", "luna-lambda-unit"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_FACES_SAMPLES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_EVENTS_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5040", "api_version": 2},
        newDefaultValue={"origin": "http://127.0.0.1:5040", "api_version": 2},
        oldDescription="LUNA Events address",
        newDescription="LUNA Events address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_FACES_SAMPLES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-samples",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-samples",
        },
        oldDescription="Address of service for storing samples",
        newDescription="Address of service for storing samples",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_FACES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5030", "api_version": 3},
        newDefaultValue={"origin": "http://127.0.0.1:5030", "api_version": 3},
        oldDescription="LUNA Faces address",
        newDescription="LUNA Faces address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5220", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5220", "api_version": 1},
        oldDescription="Address of service for remote image estimation",
        newDescription="Address of service for remote image estimation",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-handlers"],
        newServices=["luna-admin", "luna-api", "luna-handlers", "luna-lambda-unit"],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-image-origin",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-image-origin",
        },
        oldDescription="Address of service for storing origin images",
        newDescription="Address of service for storing origin images",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="STORAGE_TIME",
        oldValidationSchema={"type": "string", "enum": ["LOCAL", "UTC"]},
        newValidationSchema={"type": "string", "enum": ["LOCAL", "UTC"]},
        oldDefaultValue="LOCAL",
        newDefaultValue="LOCAL",
        oldDescription="Time in which records are stored in the database",
        newDescription="Time in which records are stored in the database",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-accounts",
            "luna-backport3",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        newServices=[
            "luna-accounts",
            "luna-backport3",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-lambda",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_FACES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-faces service",
        newDescription="timeouts for http-request to luna-faces service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-backport4", "luna-handlers", "luna-tasks"],
        newServices=[
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_PYTHON_MATCHER_PROXY_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-matcher-proxy service",
        newDescription="timeouts for http-request to luna-matcher-proxy service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers"],
        newServices=["luna-api", "luna-handlers", "luna-lambda-unit"],
    ),
    LimitationToModify(
        limitationName="LUNA_MATCHER_PROXY_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5110", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5110", "api_version": 1},
        oldDescription="LUNA Python Matcher Proxy address",
        newDescription="LUNA Python Matcher Proxy address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_BODIES_SAMPLES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        oldDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-bodies-samples",
        },
        newDefaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-bodies-samples",
        },
        oldDescription="Address of service for storing bodies samples",
        newDescription="Address of service for storing bodies samples",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
                "luna_lambda": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
                "luna_lambda",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
        },
        newDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
            "luna_lambda": False,
        },
        oldDescription="whether to use nested optional services",
        newDescription="whether to use nested optional services",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=upgradeASU,
        settingDowngradeFunction=downgradeASU,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-lambda",
            "luna-lambda-unit",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="INFLUX_MONITORING",
        oldValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        newValidationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "organization": {"type": "string"},
                "token": {"type": "string"},
                "bucket": {"type": "string"},
            },
            "default": {
                "send_data_for_monitoring": 1,
                "use_ssl": 0,
                "flushing_period": 1,
                "host": "127.0.0.1",
                "port": 8086,
                "organization": "luna",
                "token": "secret-token",
                "bucket": "luna_monitoring",
            },
            "required": [
                "send_data_for_monitoring",
                "host",
                "port",
                "organization",
                "token",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
            "description": "Monitoring settings.",
        },
        oldDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        newDefaultValue={
            "send_data_for_monitoring": 1,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "bucket": "luna_monitoring",
            "organization": "luna",
            "token": "secret-token",
        },
        oldDescription="monitoring parameters",
        newDescription="monitoring parameters",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
        newServices=[
            "luna-accounts",
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-lambda",
            "luna-lambda-unit",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-sender",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_IMAGE_STORE_IMAGES_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-image-store service",
        newDescription="timeouts for http-request to luna-image-store service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-remote-sdk", "luna-tasks"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-unit",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_LICENSES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        oldDescription="LUNA Licenses address",
        newDescription="LUNA Licenses address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api", "luna-faces", "luna-remote-sdk"],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-faces",
            "luna-lambda",
            "luna-remote-sdk",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_SENDER_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5080", "api_version": 2},
        newDefaultValue={"origin": "http://127.0.0.1:5080", "api_version": 2},
        oldDescription="LUNA Sender address",
        newDescription="LUNA Sender address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-admin", "luna-api"],
        newServices=["luna-admin", "luna-api", "luna-lambda-unit"],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="CLUSTER_CREDENTIALS",
        validationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "token": {"type": "string"},
                "certificate_path": {"type": "string"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "host": "https://127.0.0.1:6443",
            "token": "",
            "certificate_path": "cert.crt",
        },
        description="k8s cluster credentials",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="CLUSTER_LOCATION",
        validationSchema={"type": "string", "enum": ["remote", "local", "internal"]},
        defaultValue="remote",
        description="k8s cluster location: remote/local(executed on same machine)/internal(executed in cluster)",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LAMBDA_INSECURE_REGISTRIES",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="user plugin insecure registries",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LAMBDA_REGISTRY",
        validationSchema={"type": "string"},
        defaultValue="",
        description="lambda registry",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LAMBDA_S3",
        validationSchema={
            "properties": {
                "host": {"type": "string"},
                "region": {"type": "string"},
                "aws_public_access_key": {"type": "string"},
                "aws_secret_access_key": {"type": "string"},
                "authorization_signature": {"type": "string", "enum": ["s3v2", "s3v4"]},
                "request_timeout": {"type": "integer"},
                "connect_timeout": {"type": "integer"},
                "bucket": {"type": "string"},
                "verify_ssl": {"type": "boolean"},
            },
            "required": [
                "host",
                "aws_public_access_key",
                "aws_secret_access_key",
                "authorization_signature",
                "bucket",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "bucket": "lambda_bucket",
            "verify_ssl": True,
        },
        description="AWS S3 settings for lambda",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list of luna-lambda active plugins",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5210", "api_version": 1},
        description="LUNA Lambda address",
        services=["luna-admin", "luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_DB",
        validationSchema={
            "properties": {
                "db_type": {"type": "string", "enum": ["postgres", "oracle"]},
                "dsn": {
                    "type": "string",
                    "pattern": "^(?:(?P<user>.*?)(?::(?P<passwd>.*))@)?(?P<net>[^\\?\\/]*)(?:\\/(?P<dbname>[^\\?]*)(?:\\?(?P<params>[^\\?]*))?)?$",
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "db_settings": {
                    "type": "object",
                    "properties": {"connection_pool_size": {"type": "integer", "minimum": 1}},
                    "required": ["connection_pool_size"],
                    "additionalProperties": False,
                },
            },
            "required": [
                "db_type",
                "db_settings",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_lambda",
            "db_host": "127.0.0.1",
            "db_port": 5432,
            "db_settings": {"connection_pool_size": 5},
        },
        description="Main database for luna-lambda service",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Lambda http settings",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json"]},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
            "format": "default",
        },
        description="Luna Lambda logger settings",
        services=["luna-lambda"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-lambda service",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_UNIT_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list of luna-lambda-unit active plugins",
        services=["luna-lambda-unit"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_UNIT_HTTP_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "request_timeout": {"type": "integer", "minimum": 1},
                "response_timeout": {"type": "integer", "minimum": 1},
                "request_max_size": {"type": "integer", "minimum": 1},
                "keep_alive_timeout": {"type": "integer", "minimum": 1},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "request_timeout": 60,
            "response_timeout": 600,
            "request_max_size": 1073741824,
            "keep_alive_timeout": 200,
        },
        description="Luna Lambda Unit http settings",
        services=["luna-lambda-unit"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_UNIT_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
                "format": {"type": "string", "enum": ["default", "json"]},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": False,
            "multiline_stack_trace": True,
            "format": "default",
        },
        description="Luna Lambda Unit logger settings",
        services=["luna-lambda-unit"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LAMBDA_UNIT_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to lambda unit",
        services=["luna-handlers"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="CLUSTER_CREDENTIALS")
    mh.removeLimitation(limitationName="CLUSTER_LOCATION")
    mh.removeLimitation(limitationName="LAMBDA_INSECURE_REGISTRIES")
    mh.removeLimitation(limitationName="LAMBDA_REGISTRY")
    mh.removeLimitation(limitationName="LAMBDA_S3")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_DB")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_LOGGER")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_UNIT_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_UNIT_HTTP_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_UNIT_LOGGER")
    mh.removeLimitation(limitationName="LUNA_LAMBDA_UNIT_TIMEOUTS")
