"""
Configs migration

Generation datetime: 2023-10-24 12:49:05.220174
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "b1460ea0"
DOWN_REVISION = "33868d03"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to remove
    mh.removeLimitation(limitationName="FETCH_EXTERNAL_IMAGE_TIMEOUTS")

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to add
    mh.addLimitation(
        limitationName="FETCH_EXTERNAL_IMAGE_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 10,
            "connect": 10,
            "sock_connect": 10,
            "sock_read": 10,
        },
        description="timeouts for http-request to external resource for fetch image",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
