"""
Configs migration

Generation datetime: 2024-02-27 05:24:07.224749
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "080a1b4d"
DOWN_REVISION = "c40cf267"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="DEFAULT_FACE_DESCRIPTOR_VERSION",
        oldDefaultValue=59,
        newDefaultValue=62,
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
        newServices=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
