"""
Configs migration

Generation datetime: 2024-03-05 13:45:13.398610
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "73a100fe"
DOWN_REVISION = "e73f0f79"


def downgradeFunction(setting: dict):
    if setting["decoder_device_class"] not in ("cpu", "auto"):
        setting["decoder_device_class"] = "auto"
    return setting


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_REMOTE_SDK_VIDEO_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {"type": "string", "enum": ["cpu", "auto"]},
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "decoder_device_class": {"type": "string", "enum": ["cpu", "gpu", "auto"]},
                "decoder_worker_count": {"type": "integer", "minimum": 1},
                "storage": {"type": "string"},
                "max_size": {"type": "integer", "minimum": 1},
            },
            "description": "sdk video processing settings",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "storage": "./videos",
            "max_size": 1024,
        },
        newDefaultValue={
            "decoder_device_class": "auto",
            "decoder_worker_count": 10,
            "storage": "./videos",
            "max_size": 1024,
        },
        oldDescription="luna-remote-sdk video processing settings",
        newDescription="luna-remote-sdk video processing settings",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=downgradeFunction,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-remote-sdk"],
        newServices=["luna-remote-sdk"],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
